// ============================================================================
//
// CBP_rhs_hexapod.c
// Hexapod CPG	For CBP_Hexapod_2
// CBP 03-12-20 incipit
// 26-12-21 Rev.1
//		
// ============================================================================

#include <math.h>
#include <stdio.h>
#include "CBP_rhs_hexapod.h"

// Parameters
double alpha, mu, omega, tau, k;
double thresh, drive;

void setParams(double alpha_,  double mu_, double omega_, double tau_, double k_, double thresh_) {
    alpha = alpha_;
	mu = mu_;
	omega = omega_;
	tau = tau_;
	k = k_;
	thresh = thresh_;	
}

// Naming neurons --------------------------------------------------------------
// Feet-------------------------
// Neuron	       ODE index
// LF		0	
// LM		4
// LR		7
// RF		10		
// RM		13		
// RR		16

// Legs ------------------------
// Neuron	       ODE index
// LF_l		17	
// LM_l		18
// LR_l		19
// RF_l		20		
// RM_l		21		
// RR_l		22

void rhs_hexapod(double t, double y[], double dydt[]) {
double r,tau1,k1;

// ------------ c Oscillator ---------------------------------------------------
r= sqrt(y[0]*y[0] + y[1]*y[1]);
// Oscillator driving the front left foot
dydt[0] = alpha*(mu - r*r)*y[0] - omega*y[1];
dydt[1] = omega*y[0] + alpha*(mu - r*r)*y[1];

// Chain of phase shifts down the left
// Left middle foot
dydt[2] = 0;
dydt[3] = 0;
dydt[4] = 0;
// left rear foot
dydt[5] = 0;
dydt[6] = 0;
dydt[7] = 0;

// Now make 180 degree phse shifts to the right feet
// First set up the parameters to give 180 degrees
tau1 = tan(M_PI/3)/omega;
k1 = sqrt(tau1*tau1*omega*omega + 1);
// Right front foot
dydt[8] = 0;
dydt[9] = 0;
dydt[10] = 0;

// Right middle foot
dydt[11] = 0;
dydt[12] = 0;
dydt[13] = 0;

// Right rear foot
dydt[14] = 0;
dydt[15] = 0;
dydt[16] = 0;

// Neurons to provide swing-stance drive signal to the legs
// Left front leg
if( y[0] > thresh) drive = 1; else drive = 0;
dydt[17] = 0;
// Left middle leg
if( y[4] > thresh) drive = 1; else drive = 0;
dydt[18] = 0;
// Left rear leg
if( y[7] > thresh) drive = 1; else drive = 0;
dydt[19] = 0;
// Right front leg
if( y[10] > thresh) drive = 1; else drive = 0;
dydt[20] = 0;
// Right middle leg
if( y[13] > thresh) drive = 1; else drive = 0;
dydt[21] = 0;
// Right rear leg
if( y[16] > thresh) drive = 1; else drive = 0;
dydt[22] = 0;

// All done, let's return
  return;
}

